==> freecad_0.16.6712%2Bdfsg1.orig.tar.xz: FreeCAD-0.16.6712/src/Mod/OpenSCAD/Resources/translations/OpenSCAD.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0">
<context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
        <location filename="openscadprefs-base.ui" line="14"/>
        <source>General settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="26"/>
        <source>General OpenSCAD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="34"/>
        <source>OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="47"/>
        <source>The path to the OpenSCAD executeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="65"/>
        <source>OpenSCAD import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="93"/>
        <source>Use ViewProvider in Tree View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="110"/>
        <source>If this is checked, Multmatrix Object will be Parametric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="113"/>
        <source>Use Multmatrix Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="153"/>
        <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="133"/>
        <source>Maximum number of faces for polygons (fn)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="177"/>
        <source>OpenSCAD export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="185"/>
        <source>maximum fragment size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="215"/>
        <source>minimum angle for a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="208"/>
        <source>angular (fa)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="openscadprefs-base.ui" line="218"/>
        <source>°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="272"/>
        <source>minimum size of a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="250"/>
        <source>size (fs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="278"/>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="304"/>
        <source>convexity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="341"/>
        <source>Mesh fallback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="383"/>
        <source>Deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="386"/>
        <source>deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="393"/>
        <source>Triangulation settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="90"/>
        <source>If this is checked, Features will claim their children in the tree view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="73"/>
        <source>Print debug information in the Console</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD</name>
    <message>
        <location filename="OpenSCADCommands.py" line="141"/>
        <source>Convert Edges to Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="220"/>
        <source>Please select 3 objects first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1118"/>
        <source>Unsupported Function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1118"/>
        <source>Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="264"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="265"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="266"/>
        <source>as Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="267"/>
        <source>Add OpenSCAD Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="340"/>
        <source>Perform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="341"/>
        <source>Mesh Boolean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADUtils.py" line="560"/>
        <source>Error all shapes must be either 2D or both must be 3D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="91"/>
        <source>Unable to explode %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
        <location filename="OpenSCADCommands.py" line="382"/>
        <source>Add OpenSCAD Element...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="384"/>
        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
        <location filename="OpenSCADCommands.py" line="118"/>
        <source>Color Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="120"/>
        <source>Color Shapes by validity and type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
        <location filename="OpenSCADCommands.py" line="139"/>
        <source>Convert Edges To Faces</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
        <location filename="OpenSCADCommands.py" line="200"/>
        <source>Expand Placements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="202"/>
        <source>Expand all placements downwards the FeatureTree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
        <location filename="OpenSCADCommands.py" line="100"/>
        <source>Explode Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="102"/>
        <source>remove fusion, apply placement to children and color randomly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Hull</name>
    <message>
        <location filename="OpenSCADCommands.py" line="417"/>
        <source>Hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="419"/>
        <source>Perform Hull</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="181"/>
        <source>Increase Tolerance Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="183"/>
        <source>Create Feature that allows to increase the tolerance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
        <location filename="OpenSCADCommands.py" line="396"/>
        <source>Mesh Boolean...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="398"/>
        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Minkowski</name>
    <message>
        <location filename="OpenSCADCommands.py" line="438"/>
        <source>Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="440"/>
        <source>Perform Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="160"/>
        <source>Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="162"/>
        <source>Create Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
        <location filename="OpenSCADCommands.py" line="239"/>
        <source>Remove Objects and their Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="241"/>
        <source>Removes the selected objects and all children that are not referenced from other objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
        <location filename="OpenSCADCommands.py" line="224"/>
        <source>Replace Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="226"/>
        <source>Replace an object in the Feature Tree. Please select old, new and parent object</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbech</name>
    <message>
        <location filename="InitGui.py" line="80"/>
        <source>OpenSCAD Part tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="InitGui.py" line="78"/>
        <source>OpenSCADTools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/OpenSCAD/Resources/translations/OpenSCAD.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1">
<context>
    <name>Gui::Dialog::DlgSettingsOpenSCAD</name>
    <message>
        <location filename="openscadprefs-base.ui" line="14"/>
        <source>General settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="26"/>
        <source>General OpenSCAD Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="34"/>
        <source>OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="65"/>
        <source>OpenSCAD import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="93"/>
        <source>Use ViewProvider in Tree View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="110"/>
        <source>If this is checked, Multmatrix Object will be Parametric</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="113"/>
        <source>Use Multmatrix Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="153"/>
        <source>The maximum number of faces of a polygon, prism or frustum. If fn is greater than this value the object is considered to be a circular. Set to 0 for no limit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="133"/>
        <source>Maximum number of faces for polygons (fn)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="177"/>
        <source>OpenSCAD export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="185"/>
        <source>maximum fragment size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="208"/>
        <source>angular (fa)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="openscadprefs-base.ui" line="218"/>
        <source>°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="250"/>
        <source>size (fs)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="278"/>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="304"/>
        <source>convexity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="341"/>
        <source>Mesh fallback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="383"/>
        <source>Deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="386"/>
        <source>deflection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="393"/>
        <source>Triangulation settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="90"/>
        <source>If this is checked, Features will claim their children in the tree view</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="73"/>
        <source>Print debug information in the Console</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="47"/>
        <source>The path to the OpenSCAD executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="215"/>
        <source>Minimum angle for a fragment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="openscadprefs-base.ui" line="272"/>
        <source>Minimum size of a fragment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD</name>
    <message>
        <location filename="OpenSCADCommands.py" line="149"/>
        <source>Convert Edges to Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="309"/>
        <source>Please select 3 objects first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1226"/>
        <source>Unsupported Function</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="importCSG.py" line="1226"/>
        <source>Press OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="347"/>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="348"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="349"/>
        <source>as Mesh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="350"/>
        <source>Add OpenSCAD Element</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="423"/>
        <source>Perform</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="424"/>
        <source>Mesh Boolean</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADUtils.py" line="623"/>
        <source>Error all shapes must be either 2D or both must be 3D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="102"/>
        <source>Unable to explode %s</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_AddOpenSCADElement</name>
    <message>
        <location filename="OpenSCADCommands.py" line="464"/>
        <source>Add OpenSCAD Element...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="468"/>
        <source>Add an OpenSCAD element by entering OpenSCAD code and executing the OpenSCAD binary</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ColorCodeShape</name>
    <message>
        <location filename="OpenSCADCommands.py" line="126"/>
        <source>Color Shapes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="129"/>
        <source>Color Shapes by validity and type</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Edgestofaces</name>
    <message>
        <location filename="OpenSCADCommands.py" line="146"/>
        <source>Convert Edges To Faces</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExpandPlacements</name>
    <message>
        <location filename="OpenSCADCommands.py" line="291"/>
        <source>Expand Placements</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="294"/>
        <source>Expand all placements downwards the FeatureTree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ExplodeGroup</name>
    <message>
        <location filename="OpenSCADCommands.py" line="110"/>
        <source>Explode Group</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="113"/>
        <source>Remove fusion, apply placement to children, and color randomly</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Hull</name>
    <message>
        <location filename="OpenSCADCommands.py" line="497"/>
        <source>Hull</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="500"/>
        <source>Perform Hull</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_IncreaseToleranceFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="274"/>
        <source>Increase Tolerance Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="277"/>
        <source>Create Feature that allows to increase the tolerance</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MeshBoolean</name>
    <message>
        <location filename="OpenSCADCommands.py" line="477"/>
        <source>Mesh Boolean...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="481"/>
        <source>Export objects as meshes and use OpenSCAD to perform a boolean operation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_Minkowski</name>
    <message>
        <location filename="OpenSCADCommands.py" line="516"/>
        <source>Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="519"/>
        <source>Perform Minkowski</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_MirrorMeshFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="195"/>
        <source>Mirror Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="198"/>
        <source>Create Mirror Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RefineShapeFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="165"/>
        <source>Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="168"/>
        <source>Create Refine Shape Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_RemoveSubtree</name>
    <message>
        <location filename="OpenSCADCommands.py" line="324"/>
        <source>Remove Objects and their Children</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="327"/>
        <source>Removes the selected objects and all children that are not referenced from other objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ReplaceObject</name>
    <message>
        <location filename="OpenSCADCommands.py" line="312"/>
        <source>Replace Object</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="315"/>
        <source>Replace an object in the Feature Tree. Please select old, new, and parent object</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ResizeMeshFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="254"/>
        <source>Resize Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="258"/>
        <source>Create Resize Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSCAD_ScaleMeshFeature</name>
    <message>
        <location filename="OpenSCADCommands.py" line="224"/>
        <source>Scale Mesh Feature...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="OpenSCADCommands.py" line="228"/>
        <source>Create Scale Mesh Feature</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbech</name>
    <message>
        <location filename="InitGui.py" line="83"/>
        <source>OpenSCAD Part tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Workbench</name>
    <message>
        <location filename="InitGui.py" line="81"/>
        <source>OpenSCADTools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
